==> material-react-table-2.0.1.tgz: package/locales/fr/index.esm.js <==
const MRT_Localization_FR = {
    actions: 'Actions',
    and: 'et',
    cancel: 'Annuler',
    changeFilterMode: 'Changer le mode de filtre',
    changeSearchMode: 'Changer le mode de recherche',
    clearFilter: 'Effacer le filtre',
    clearSearch: 'Effacer la recherche',
    clearSort: 'Effacer le tri',
    clickToCopy: 'Cliquer pour copier',
    collapse: 'Réduire',
    collapseAll: 'Réduire tout',
    columnActions: 'Actions de colonne',
    copiedToClipboard: 'Copié dans le presse-papier',
    dropToGroupBy: 'Déposer pour grouper par {column}',
    edit: 'Editer',
    expand: 'Développer',
    expandAll: 'Tout développer',
    filterArrIncludes: 'Inclure',
    filterArrIncludesAll: 'Tout inclure',
    filterArrIncludesSome: 'Inclure',
    filterBetween: 'Entre',
    filterBetweenInclusive: 'Entre inclus',
    filterByColumn: 'Filtrer par {column}',
    filterContains: 'Contient',
    filterEmpty: 'Vide',
    filterEndsWith: 'Se termine par',
    filterEquals: 'Egale',
    filterEqualsString: 'Egale',
    filterFuzzy: 'Flou',
    filterGreaterThan: 'Plus grand que',
    filterGreaterThanOrEqualTo: 'Plus grand que ou égale à',
    filterInNumberRange: 'Entre',
    filterIncludesString: 'Contient',
    filterIncludesStringSensitive: 'Contient',
    filterLessThan: 'Plus petit que',
    filterLessThanOrEqualTo: 'Plus petit que ou égale à',
    filterMode: 'Mode filtre: {filterType}',
    filterNotEmpty: 'Pas vide',
    filterNotEquals: 'Pas égal',
    filterStartsWith: 'Commence avec',
    filterWeakEquals: 'Egale',
    filteringByColumn: 'Filtrage par {column} - {filterType} {filterValue}',
    goToFirstPage: 'Aller à la première page',
    goToLastPage: 'Aller à la dernière page',
    goToNextPage: 'Aller à la page suivante',
    goToPreviousPage: 'Aller à la page précédente',
    grab: 'Saisir',
    groupByColumn: 'Grouper par {column}',
    groupedBy: 'Groupé par ',
    hideAll: 'Cacher tout',
    hideColumn: 'Cacher {column} colonne',
    max: 'Max',
    min: 'Min',
    move: 'Déplacer',
    noRecordsToDisplay: 'Aucun enregistrement à afficher',
    noResultsFound: 'Aucun résultat trouvé',
    of: 'de',
    or: 'ou',
    pin: 'Attacher',
    pinToLeft: 'Épingler à gauche',
    pinToRight: 'Épingler à droite',
    resetColumnSize: 'Réinitialiser la taille de la colonne',
    resetOrder: "Réinitialiser l'ordre",
    rowActions: 'Actions de ligne',
    rowNumber: '#',
    rowNumbers: 'Numéros de ligne',
    rowsPerPage: 'Lignes par page',
    save: 'Sauvegarder',
    search: 'Rechercher',
    selectedCountOfRowCountRowsSelected: '{selectedCount} sur {rowCount} ligne(s)',
    select: 'Sélectionner',
    showAll: 'Afficher tous',
    showAllColumns: 'Afficher toutes les colonnes',
    showHideColumns: 'Afficher/Masquer les colonnes',
    showHideFilters: 'Afficher/Masquer les filtres',
    showHideSearch: 'Afficher/Masquer la recherche',
    sortByColumnAsc: 'Trier par {column} croissant',
    sortByColumnDesc: 'Trier par {column} décroissant',
    sortedByColumnAsc: 'Trié par {column} croissant',
    sortedByColumnDesc: 'Trié par {column} décroissant',
    thenBy: ', puis par ',
    toggleDensity: 'Changer la densité',
    toggleFullScreen: 'Passer en plein écran',
    toggleSelectAll: 'Basculer tout sélectionner',
    toggleSelectRow: 'Basculer la sélection de ligne',
    toggleVisibility: 'Basculer la visibilité',
    ungroupByColumn: 'Dissocier par {column}',
    unpin: 'Détacher',
    unpinAll: 'Tout détacher',
};

export { MRT_Localization_FR };

==> material-react-table-2.4.0.tgz: package/locales/fr/index.esm.js <==
const MRT_Localization_FR = {
    actions: 'Actions',
    and: 'et',
    cancel: 'Annuler',
    changeFilterMode: 'Changer le mode de filtre',
    changeSearchMode: 'Changer le mode de recherche',
    clearFilter: 'Effacer le filtre',
    clearSearch: 'Effacer la recherche',
    clearSort: 'Effacer le tri',
    clickToCopy: 'Cliquer pour copier',
    collapse: 'Réduire',
    collapseAll: 'Réduire tout',
    columnActions: 'Actions de colonne',
    copiedToClipboard: 'Copié dans le presse-papier',
    dropToGroupBy: 'Déposer pour grouper par {column}',
    edit: 'Editer',
    expand: 'Développer',
    expandAll: 'Tout développer',
    filterArrIncludes: 'Inclure',
    filterArrIncludesAll: 'Tout inclure',
    filterArrIncludesSome: 'Inclure',
    filterBetween: 'Entre',
    filterBetweenInclusive: 'Entre inclus',
    filterByColumn: 'Filtrer par {column}',
    filterContains: 'Contient',
    filterEmpty: 'Vide',
    filterEndsWith: 'Se termine par',
    filterEquals: 'Egale',
    filterEqualsString: 'Egale',
    filterFuzzy: 'Flou',
    filterGreaterThan: 'Plus grand que',
    filterGreaterThanOrEqualTo: 'Plus grand que ou égale à',
    filterInNumberRange: 'Entre',
    filterIncludesString: 'Contient',
    filterIncludesStringSensitive: 'Contient',
    filterLessThan: 'Plus petit que',
    filterLessThanOrEqualTo: 'Plus petit que ou égale à',
    filterMode: 'Mode filtre: {filterType}',
    filterNotEmpty: 'Pas vide',
    filterNotEquals: 'Pas égal',
    filterStartsWith: 'Commence avec',
    filterWeakEquals: 'Egale',
    filteringByColumn: 'Filtrage par {column} - {filterType} {filterValue}',
    goToFirstPage: 'Aller à la première page',
    goToLastPage: 'Aller à la dernière page',
    goToNextPage: 'Aller à la page suivante',
    goToPreviousPage: 'Aller à la page précédente',
    grab: 'Saisir',
    groupByColumn: 'Grouper par {column}',
    groupedBy: 'Groupé par ',
    hideAll: 'Cacher tout',
    hideColumn: 'Cacher colonne {column}',
    max: 'Max',
    min: 'Min',
    move: 'Déplacer',
    noRecordsToDisplay: 'Aucun enregistrement à afficher',
    noResultsFound: 'Aucun résultat trouvé',
    of: 'de',
    or: 'ou',
    pin: 'Attacher',
    pinToLeft: 'Épingler à gauche',
    pinToRight: 'Épingler à droite',
    resetColumnSize: 'Réinitialiser la taille de la colonne',
    resetOrder: "Réinitialiser l'ordre",
    rowActions: 'Actions de ligne',
    rowNumber: '#',
    rowNumbers: 'Numéros de ligne',
    rowsPerPage: 'Lignes par page',
    save: 'Sauvegarder',
    search: 'Rechercher',
    selectedCountOfRowCountRowsSelected: '{selectedCount} sur {rowCount} ligne(s)',
    select: 'Sélectionner',
    showAll: 'Afficher tous',
    showAllColumns: 'Afficher toutes les colonnes',
    showHideColumns: 'Afficher/Masquer les colonnes',
    showHideFilters: 'Afficher/Masquer les filtres',
    showHideSearch: 'Afficher/Masquer la recherche',
    sortByColumnAsc: 'Trier par {column} croissant',
    sortByColumnDesc: 'Trier par {column} décroissant',
    sortedByColumnAsc: 'Trié par {column} croissant',
    sortedByColumnDesc: 'Trié par {column} décroissant',
    thenBy: ', puis par ',
    toggleDensity: 'Changer la densité',
    toggleFullScreen: 'Passer en plein écran',
    toggleSelectAll: 'Basculer tout sélectionner',
    toggleSelectRow: 'Basculer la sélection de ligne',
    toggleVisibility: 'Basculer la visibilité',
    ungroupByColumn: 'Dissocier par {column}',
    unpin: 'Détacher',
    unpinAll: 'Tout détacher',
};

export { MRT_Localization_FR };
